--- channels/chan_sip.org	2006-05-09 16:03:22.567818095 -0400
+++ channels/chan_sip.c	2006-05-09 17:13:15.129095616 -0400
@@ -923,6 +923,8 @@
 static int transmit_state_notify(struct sip_pvt *p, int state, int full, int substate);
 static char *gettag(struct sip_request *req, char *header, char *tagbuf, int tagbufsize);
 
+int is_sdpofmultipart(struct sip_request *req); 
+
 /*! \brief Definition of this channel for PBX channel registration */
 static const struct ast_channel_tech sip_tech = {
 	.type = channeltype,
@@ -3444,7 +3446,8 @@
 	time(&p->lastrtptx);
 
 	/* Get codec and RTP info from SDP */
-	if (strcasecmp(get_header(req, "Content-Type"), "application/sdp")) {
+	if (strcasecmp(get_header(req, "Content-Type"), "application/sdp") &&
+	   (!is_sdpofmultipart(req))) {
 		ast_log(LOG_NOTICE, "Content is '%s', not 'application/sdp'\n", get_header(req, "Content-Type"));
 		return -1;
 	}
@@ -9496,7 +9499,7 @@
 			if (p->owner->_state != AST_STATE_UP)
 				ast_setstate(p->owner, AST_STATE_RINGING);
 		}
-		if (!strcasecmp(get_header(req, "Content-Type"), "application/sdp")) {
+		if ((!strcasecmp(get_header(req, "Content-Type"), "application/sdp")) || is_sdpofmultipart(req)) {
 			process_sdp(p, req);
 			if (!ignore && p->owner) {
 				/* Queue a progress frame only if we have SDP in 180 */
@@ -9507,7 +9510,7 @@
 	case 183:	/* Session progress */
 		sip_cancel_destroy(p);
 		/* Ignore 183 Session progress without SDP */
-		if (!strcasecmp(get_header(req, "Content-Type"), "application/sdp")) {
+		if ((!strcasecmp(get_header(req, "Content-Type"), "application/sdp")) || is_sdpofmultipart(req)) {
 			process_sdp(p, req);
 			if (!ignore && p->owner) {
 				/* Queue a progress frame */
@@ -9518,7 +9521,7 @@
 	case 200:	/* 200 OK on invite - someone's answering our call */
 		sip_cancel_destroy(p);
 		p->authtries = 0;
-		if (!strcasecmp(get_header(req, "Content-Type"), "application/sdp")) {
+		if ((!strcasecmp(get_header(req, "Content-Type"), "application/sdp")) || is_sdpofmultipart(req)) {
 			process_sdp(p, req);
 		}
 
@@ -10335,7 +10338,8 @@
 		check_via(p, req);
 		if (p->owner) {
 			/* Handle SDP here if we already have an owner */
-			if (!strcasecmp(get_header(req, "Content-Type"), "application/sdp")) {
+			if (!strcasecmp(get_header(req, "Content-Type"), "application/sdp") ||
+			    (is_sdpofmultipart(req))) {
 				if (process_sdp(p, req)) {
 					transmit_response(p, "488 Not acceptable here", req);
 					if (!p->lastinvite)
@@ -13313,3 +13317,34 @@
 	return (char *) desc;
 }
 
+
+int is_sdpofmultipart(struct sip_request *req) 
+{
+	int x, len;
+	char *type, *next;
+	char boundary[100];
+
+	type = get_header(req, "Content-Type");
+	if (strncasecmp(type,"multipart/mixed", 15))
+			return 0;
+
+	/* find our boundary name from the Content-Type header */
+	next = type;
+	while(*next++ != ';') ;
+	while (*next++ != '=') ;
+
+	/* append -- */
+	strcpy(boundary, "--");
+	len = strlen(next);
+	if (len < 100)
+		strcat(boundary, next);
+
+	for (x=0; x < (req->lines - 1); x++) {
+		if (!strncasecmp(req->line[x], boundary, strlen(boundary)) &&
+		    !strcasecmp(req->line[x+1], "Content-Type: application/sdp")) {
+			return 1;
+		}
+	}
+
+	return 0;
+}
